#include <climits>
#include <cstdio>

using namespace std;

const int MAXN = 100000;
const long long int INF = (static_cast<long long int>(2) << 60) / 2;

class Node {
	public:
       	int d;
        int len;
        Node* next;
};

int N;
int M;
Node* adj[MAXN + 1];
long long int farthest[MAXN + 1];
long long int dist[MAXN + 1];//!
int heap[MAXN + 1];
int heap_p[MAXN + 1];
int heap_N;

void heap_sentinel() {
	heap[0] = 0;
        dist[0] = 0;//!
}

void insertBefore(Node*& l, int ad, int alen) {
	Node* p = new Node;
        p->d = ad;
        p->len = alen;
        p->next = l;
        l = p;
}

void heap_up(int si) {
	int x = si;
        int y = heap[si];
        while (dist[y] < dist[heap[x / 2]]) {
        	heap[x] = heap[x / 2];
                heap_p[heap[x]] = x;
        	x /= 2;
        }
        heap[x] = y;
        heap_p[heap[x]] = x;
}

void heap_down(int si) {
	int x = si;
        int y = heap[si];
        for ( ; ; ) {
        	int li = 2 * x;
                int ri = 2 * x + 1;
                if (li > heap_N) {
                	//0
                        break;
                } else if (ri > heap_N) {
                	//1
                        if (dist[y] > dist[heap[li]]) {
                        	heap[x] = heap[li];
                                heap_p[heap[x]] = x;
                                x = li;
                        } else break;
                } else {
                	//2
                        if (dist[y] < dist[heap[li]] && dist[y] < dist[heap[ri]]) {
                        	break;
                        }
                        if (dist[heap[li]] < dist[heap[ri]]) {
                                heap[x] = heap[li];
                                heap_p[heap[x]] = x;
                                x = li;
                        } else {
                        	heap[x] = heap[ri];
                                heap_p[heap[x]] = x;
                                x = ri;
                        }
                }
        }
        heap[x] = y;
        heap_p[heap[x]] = x;
}

int heap_get() {
	int result = heap[1];
        heap[1] = heap[heap_N];
        heap_N--;
        heap_down(1);
        return result;
}

void heap_put(int x) {
	heap_N++;
        heap[heap_N] = x;
        heap_up(heap_N);
}

void dijkstra(int start) {
        for (int i = 1; i <= N; i++) {
        	dist[i] = INF;
        }
        dist[start] = 0;
	//init heap
        for (int i = 1; i <= N; i++) {
        	heap[i] = i;
                heap_p[i] = i;
        }
        heap_N = N;
        heap_up(heap_p[start]);
        int left = N - start;
        for ( ; ; ) {
                if (left == 0) break;
        	if (heap_N == 0) break;
        	int cur = heap_get();
                //printf("cur=%d\n", cur);
                if (cur > start) left--;
                for (Node* p = adj[cur]; p != NULL; p = p->next) {
                	//printf("cur=%d p->d=%d\n", cur, p->d);
                	int tmp = dist[cur] + p->len;
                	if (tmp < dist[p->d]) {
                        	dist[p->d] = tmp;
                                heap_up(heap_p[p->d]);
                        }
                }
        }
        /*
        printf("start=%d\n", start);
        for (int i = 0; i <= N; i++) {
        	printf("dist[%d]=%lld\n", i, dist[i]);
        }
        */

        for (int i = start + 1; i <= N; i++) {
        	//if (dist[i] != INF) {
	        	if (dist[i] > farthest[start]) {
	                	farthest[start] = dist[i];
	                }
                //}
        }

        for (int i = start + 1; i <= N; i++) {
        	//if (dist[i] != INF) {
	        	if (dist[i] > farthest[i]) {
        	        	farthest[i] = dist[i];
	                }
                //}
        }
}

int main() {
	scanf("%d%d", &N, &M);
        for (int i = 1; i <= N; i++) {
        	adj[i] = NULL;
        }
        for (int i = 0; i < M; i++) {
        	int A, B, C;
                scanf("%d%d%d", &A, &B, &C);
                insertBefore(adj[A], B, C);
                insertBefore(adj[B], A, C);
        }

        for (int i = 1; i <= N; i++) {
        	farthest[i] = 0;
        }
        heap_sentinel();
        for (int i = 1; i <= N - 1; i++) {
        	dijkstra(i);
        }
        //printf("INF=%lld\n", INF);
        for (int i = 1; i <= N; i++) {
        	printf("%lld\n", farthest[i]);
        }
}
